#Framy  
##A simple web framework

This is a low level mirco webframe work that you can use. 
For documentation please see a276me.cn/docs.  
Github page: ***

#### Reasons why Framy is awesome

- You can directly control low-end sockets
- It is a low level framework that anyone can add to or edit


